@@ -1,6 +1,6 @@
 /* io.c
  *
- * $Id: io.c,v 1.31 2002/10/14 08:05:38 bazsi Exp $ */
+ * $Id: io.c,v 1.32 2002/11/12 07:42:56 bazsi Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -1024,13 +1024,17 @@ struct address_info *sockaddr2address_info(size_t addr_len,
 		struct sockaddr_un *un = (struct sockaddr_un *) addr;
 		return &make_unix_address(c_format("%z", un->sun_path))->super;
 	}
+	case AF_UNSPEC:
+		break;
 #if 0
 	case AF_INETv6:
 		break;
 #endif
 	default:
-		fatal("io.c: sockaddr2info(): Unsupported address family %i.\n", addr->sa_family);
+		werror("io.c: sockaddr2info(): Unsupported address family %i (addrlen=%i).\n", addr->sa_family, addr_len);
+		break;
 	}
+	return NULL;
 }
 
 #if 0
